@@ -9,6 +9,7 @@ from flask.ext.login import LoginManager, AnonymousUserMixin, login_user
 from raven.base import Client
 from raven.contrib.flask import Sentry
 from raven.utils.testutils import TestCase
+from raven.handlers.logging import SentryHandler
 
 
 class TempStoreClient(Client):
@@ -125,6 +126,12 @@ class FlaskTest(BaseTest):
         self.assertEquals(event['message'], 'ValueError: hello world')
         self.assertEquals(event['culprit'], 'tests.contrib.flask.tests in an_error')
 
+    def test_capture_plus_logging(self):
+        client, raven, app = self.make_client_and_raven(debug=False)
+        app.logger.addHandler(SentryHandler(raven))
+        client.get('/an-error/')
+        assert len(raven.events) == 1
+
     def test_get(self):
         response = self.client.get('/an-error/?foo=bar')
         self.assertEquals(response.status_code, 500)
@@ -263,6 +270,19 @@ class FlaskTest(BaseTest):
             assert self.middleware.last_event_id == event_id
             assert g.sentry_event_id == event_id
 
+    def test_logging_setup_with_exclusion_list(self):
+        app = Flask(__name__)
+        raven = TempStoreClient()
+
+        Sentry(app, client=raven, logging=True,
+            logging_exclusions=("excluded_logger",))
+
+        excluded_logger = logging.getLogger("excluded_logger")
+        self.assertFalse(excluded_logger.propagate)
+
+        some_other_logger = logging.getLogger("some_other_logger")
+        self.assertTrue(some_other_logger.propagate)
+
 
 class FlaskLoginTest(BaseTest):
 
